config

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 4, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	File  string
	Debug bool
}

Config represents the configuration for the gou application.

func ParseConfig

func ParseConfig(args []string) (*Config, error)

ParseConfig parses the command-line arguments and environment variables and returns the configuration.

func (*Config) LogValue

func (cfg *Config) LogValue() slog.Value

LogValue implements the slog.LogValuer interface.

type PrintUsageError

type PrintUsageError struct {
	// Usage is the usage information to be printed.
	Usage string
}

PrintUsageError is an error type used to indicate that the usage of the application should be printed.

func (PrintUsageError) Error

func (PrintUsageError) Error() string

Jump to