Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
Config represents the configuration for the gou application.
func ParseConfig ¶
ParseConfig parses the command-line arguments and environment variables and returns the configuration.
type PrintUsageError ¶
type PrintUsageError struct {
// Usage is the usage information to be printed.
Usage string
}
PrintUsageError is an error type used to indicate that the usage of the application should be printed.
func (PrintUsageError) Error ¶
func (PrintUsageError) Error() string
Click to show internal directories.
Click to hide internal directories.